@@ -1,5 +1,5 @@
 package Test::Class::Moose;
-$Test::Class::Moose::VERSION = '0.60';
+$Test::Class::Moose::VERSION = '0.61';
 # ABSTRACT: Serious testing for serious Perl
 
 use 5.10.0;
@@ -10,6 +10,7 @@ use Sub::Attribute;
 
 use Test::Class::Moose::AttributeRegistry;
 use Test::Class::Moose::Config;
+use Test::Class::Moose::Deprecated;
 
 has 'test_report' => (
     is     => 'rw',
@@ -172,6 +173,13 @@ around 'BUILDARGS' => sub {
 sub runtests {
     my $self = shift;
 
+    Test::Class::Moose::Deprecated::deprecated(
+        message =>
+            'Calling runtests() on a Test::Class::Moose object is deprecated.'
+            . ' Use Test::Class::Moose::Runner instead.',
+        feature => 'Test::Class::Moose->runtests',
+    );
+
     # The only way this object won't have a _runner set is if someone calls
     # ->new() on their test class (which subclasses Test::Class::Moose) and
     # then calls ->runtests() on it, which has never been documented as
@@ -179,6 +187,7 @@ sub runtests {
     carp 'Calling runtests() on a Test::Class::Moose object is deprecated.'
         . ' Use Test::Class::Moose::Runner instead.';
 
+
     require Test::Class::Moose::Runner;
     my $runner
         = Test::Class::Moose::Runner->new( $self->_config_p );
@@ -243,7 +252,7 @@ Test::Class::Moose - Serious testing for serious Perl
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -307,6 +316,11 @@ Just C<use Test::Class::Moose>. That's all. You'll get all L<Test::Most> test
 functions, too, along with C<strict> and C<warnings>. You can use all L<Moose>
 behavior, too.
 
+When you C<use Test::Class::Moose> it inserts itself as a parent class for
+your test class. This means that if you try to use C<extends> in your test
+class you will break things unless you include C<Test::Class::Moose> as a
+parent. We recommend that you use roles in your test classes instead.
+
 =head2 Declare a test method
 
 All method names that begin with C<test_> are test methods. Methods that do
@@ -439,7 +453,7 @@ C<< $test->test_class >>, or you can do this:
     sub test_startup {
         my $test                 = shift;
         my $report               = $test->test_report;
-        my $class                = $report->current_class->name;
+        my $instance             = $report->current_instance->name;
         my $upcoming_test_method = $report->current_method->name;
         ...
     }
@@ -695,8 +709,8 @@ You can also call it in test classes (most useful in the C<test_setup()> method)
     sub test_setup {
         my $test = shift;
         $self->next::method;
-        my $report= $test->test_report;
-        my $class = $test->current_class;
+        my $report = $test->test_report;
+        my $instance = $test->current_instance;
         my $method = $test->current_method; # the test method we're about to run
         if ( $method->name =~ /customer/ ) {
             $test->load_customer_fixture;
@@ -1008,20 +1022,74 @@ L<Test::Class> + L<Test::Most>.
 
 =back
 
-=head1 AUTHOR
-
-Curtis "Ovid" Poe <ovid@cpan.org>
-
-=head1 CONTRIBUTORS
-
-=for stopwords Dave Rolsky Petrea Corneliu Stefan Steven Humphrey Stuckdownawell Tim Vroom Tom Beresford Heady Udo Oji mephinet Doug Bell Gregory Oschwald Jeremy Krieg Jonathan C. Otsuka Stowe Karen Etheridge Neil Bowers Olaf Alders Paul Boyd
+=head1 AUTHORS
 
 =over 4
 
 =item *
 
+Curtis "Ovid" Poe <ovid@cpan.org>
+
+=item *
+
 Dave Rolsky <autarch@urth.org>
 
+=back
+
+=head1 CONTRIBUTORS
+
+=for stopwords Andy Jack Doug Bell Gregory Oschwald Jeremy Krieg Jonathan C. Otsuka Stowe Karen Etheridge mark-5 mephinet Neil Bowers Olaf Alders Paul Boyd Petrea Corneliu Stefan Steven Humphrey Stuckdownawell Tim Vroom Tom Beresford Heady Udo Oji
+
+=over 4
+
+=item *
+
+Andy Jack <github@veracity.ca>
+
+=item *
+
+Doug Bell <madcityzen@gmail.com>
+
+=item *
+
+Gregory Oschwald <goschwald@maxmind.com>
+
+=item *
+
+Jeremy Krieg <Jeremy.Krieg@YourAmigo.com>
+
+=item *
+
+Jonathan C. Otsuka <djgoku@gmail.com>
+
+=item *
+
+Jonathan Stowe <jns@gellyfish.co.uk>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+mark-5 <maflick88@gmail.com>
+
+=item *
+
+mephinet <mephinet@gmx.net>
+
+=item *
+
+Neil Bowers <neil@bowers.com>
+
+=item *
+
+Olaf Alders <olaf@wundersolutions.com>
+
+=item *
+
+Paul Boyd <pboyd@dev3l.net>
+
 =item *
 
 Petrea Corneliu Stefan <stefan@garage-coding.com>
@@ -1050,46 +1118,6 @@ Tom Heady <tom@punch.net>
 
 Udo Oji <Velti@signor.com>
 
-=item *
-
-mephinet <mephinet@gmx.net>
-
-=item *
-
-Doug Bell <madcityzen@gmail.com>
-
-=item *
-
-Gregory Oschwald <goschwald@maxmind.com>
-
-=item *
-
-Jeremy Krieg <Jeremy.Krieg@YourAmigo.com>
-
-=item *
-
-Jonathan C. Otsuka <djgoku@gmail.com>
-
-=item *
-
-Jonathan Stowe <jns@gellyfish.co.uk>
-
-=item *
-
-Karen Etheridge <ether@cpan.org>
-
-=item *
-
-Neil Bowers <neil@bowers.com>
-
-=item *
-
-Olaf Alders <olaf@wundersolutions.com>
-
-=item *
-
-Paul Boyd <pboyd@dev3l.net>
-
 =back
 
 =head1 COPYRIGHT AND LICENSE
