@@ -1,5 +1,5 @@
 package Test::Class::Moose::AttributeRegistry;
-$Test::Class::Moose::AttributeRegistry::VERSION = '0.60';
+$Test::Class::Moose::AttributeRegistry::VERSION = '0.61';
 ## ABSTRACT: Global registry of tags by class and method.
 
 use strict;
@@ -117,18 +117,19 @@ sub _superclass_tags {
 
     my $test_class_meta = Class::MOP::Class->initialize($test_class);
     my $method_meta;
-    
+
     $method_meta = $test_class_meta->find_next_method_by_name($method)
-    	if $test_class_meta->can('find_next_method_by_name');
+        if $test_class_meta->can('find_next_method_by_name');
 
-    if(!$method_meta){
-	#Might be a from a role or this class
-	my $mm = $test_class_meta->find_method_by_name($method);
-	my $orig = $mm->original_method;
+    if ( !$method_meta ) {
 
-	if($orig && ($mm->package_name ne $orig->package_name)){
-		$method_meta = $orig;
-	}
+        #Might be a from a role or this class
+        my $mm   = $test_class_meta->find_method_by_name($method);
+        my $orig = $mm->original_method;
+
+        if ( $orig && ( $mm->package_name ne $orig->package_name ) ) {
+            $method_meta = $orig;
+        }
     }
 
     # no method, so no tags to inherit
@@ -185,7 +186,7 @@ Test::Class::Moose::AttributeRegistry - Global registry of tags by class and met
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -253,10 +254,20 @@ keyboard to Mark Morgan for his work on this).
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by Curtis "Ovid" Poe.
