@@ -1,5 +1,5 @@
 package Test::Class::Moose::Config;
-$Test::Class::Moose::Config::VERSION = '0.60';
+$Test::Class::Moose::Config::VERSION = '0.61';
 # ABSTRACT: Configuration information for Test::Class::Moose
 
 use 5.10.0;
@@ -60,6 +60,12 @@ has 'randomize' => (
     default => 0,
 );
 
+has 'randomize_classes' => (
+    is      => 'ro',
+    isa     => 'Bool',
+    default => 0,
+);
+
 has 'include' => (
     is  => 'ro',
     isa => 'Regexp',
@@ -111,7 +117,7 @@ Test::Class::Moose::Config - Configuration information for Test::Class::Moose
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -192,7 +198,11 @@ own if it conforms to the interface.
 
 =head2 C<randomize>
 
-Boolean. Will run tests in a random order.
+Boolean. Will run test methods of a class in a random order.
+
+=head2 C<randomize_classes>
+
+Boolean. Will run test classes in a random order.
 
 =head1 METHODS
 
@@ -241,10 +251,20 @@ L<http://search.cpan.org/dist/Test-Class-Moose/>
 
 =head1 ACKNOWLEDGEMENTS
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by Curtis "Ovid" Poe.
