@@ -1,5 +1,5 @@
 package Test::Class::Moose::Executor::Sequential;
-$Test::Class::Moose::Executor::Sequential::VERSION = '0.60';
+$Test::Class::Moose::Executor::Sequential::VERSION = '0.61';
 # ABSTRACT: Execute tests sequentially
 
 use 5.10.0;
@@ -52,12 +52,22 @@ Test::Class::Moose::Executor::Sequential - Execute tests sequentially
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by Curtis "Ovid" Poe.
