@@ -1,5 +1,5 @@
 package Test::Class::Moose::Report;
-$Test::Class::Moose::Report::VERSION = '0.60';
+$Test::Class::Moose::Report::VERSION = '0.61';
 # ABSTRACT: Test information for Test::Class::Moose
 
 use 5.10.0;
@@ -71,15 +71,25 @@ sub _inc_tests {
     $self->set_tests_run( $self->num_tests_run + $tests );
 }
 
-sub current_class {
+sub current_instance {
     my $self = shift;
     return $self->test_instances->[-1];
 }
 
+sub current_class {
+    Test::Class::Moose::Deprecated::deprecated(
+        message =>
+            'Calling current_class() on a Test::Class::Moose::Report object is deprecated.'
+            . ' Use current_instance() instead.',
+        feature => 'Test::Class::Moose->runtests',
+    );
+    goto &current_instance;
+}
+
 sub current_method {
     my $self = shift;
-    my $current_class = $self->current_class or return;
-    return $current_class->current_method;
+    my $current_instance = $self->current_instance or return;
+    return $current_instance->current_method;
 }
 
 sub plan {
@@ -101,7 +111,7 @@ Test::Class::Moose::Report - Test information for Test::Class::Moose
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -192,6 +202,16 @@ Integer. The number of test methods run.
 
 Integer. The number of tests run.
 
+=head3 C<current_instance>
+
+Returns the L<Test::Class::Moose::Report::Instance> for the test class
+instance currently being run, if it exists. This may return C<undef>.
+
+=head3 C<current_method>
+
+Returns the L<Test::Class::Moose::Report::Method> for the test method
+currently being run, if one exists. This may return C<undef>.
+
 =head3 C<time>
 
 Returns a L<Test::Class::Moose::Report::Time> object. This object
@@ -347,10 +367,20 @@ L<http://search.cpan.org/dist/Test-Class-Moose/>
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by Curtis "Ovid" Poe.
