@@ -1,5 +1,5 @@
 package Test::Class::Moose::Report::Instance;
-$Test::Class::Moose::Report::Instance::VERSION = '0.60';
+$Test::Class::Moose::Report::Instance::VERSION = '0.61';
 # ABSTRACT: Reporting on test classes
 
 use Moose;
@@ -47,7 +47,7 @@ Test::Class::Moose::Report::Instance - Reporting on test classes
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 DESCRIPTION
 
@@ -76,10 +76,20 @@ If this class could not be run, returns a string explaining the error.
 
 Returns a boolean indicating whether or not the class has an error.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by Curtis "Ovid" Poe.
