@@ -1,5 +1,5 @@
 package Test::Class::Moose::Report::Time;
-$Test::Class::Moose::Report::Time::VERSION = '0.60';
+$Test::Class::Moose::Report::Time::VERSION = '0.61';
 # ABSTRACT: Reporting object for timing
 
 use Moose;
@@ -51,7 +51,7 @@ Test::Class::Moose::Report::Time - Reporting object for timing
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 DESCRIPTION
 
@@ -88,10 +88,20 @@ method took to run. Something like:
 
   0.00177908 wallclock secs ( 0.00 usr +  0.00 sys =  0.00 CPU)
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by Curtis "Ovid" Poe.
