@@ -1,5 +1,5 @@
 package Test::Class::Moose::Role;
-$Test::Class::Moose::Role::VERSION = '0.60';
+$Test::Class::Moose::Role::VERSION = '0.61';
 # ABSTRACT: Test::Class::Moose for roles
 
 use 5.10.0;
@@ -27,6 +27,8 @@ END
 
     eval $preamble;
     croak($@) if $@;
+    strict->import;
+    warnings->import;
     no strict "refs";
     *{"$caller\::Tags"}  = \&Tags;
     *{"$caller\::Test"}  = \&Test;
@@ -45,7 +47,7 @@ Test::Class::Moose::Role - Test::Class::Moose for roles
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 DESCRIPTION
 
@@ -92,10 +94,20 @@ Note that this cannot be consumed into classes and magically make them into
 test classes. You must still (at the present time) inherit from
 C<Test::Class::Moose> to create a test suite.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by Curtis "Ovid" Poe.
