@@ -1,5 +1,5 @@
 package Test::Class::Moose::Role::AutoUse;
-$Test::Class::Moose::Role::AutoUse::VERSION = '0.60';
+$Test::Class::Moose::Role::AutoUse::VERSION = '0.61';
 # ABSTRACT: Automatically load the classes you're testing
 
 use Moose::Role;
@@ -40,7 +40,7 @@ Test::Class::Moose::Role::AutoUse - Automatically load the classes you're testin
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -132,12 +132,12 @@ Your test subclass might look like this:
 
 Object-oriented tests I<inherit> their parent class tests. Thus,
 C<TestsFor::Person::Employee> will inherit the
-C<TestsFor::Person->test_constructor()> method. Except as you can see in our
+C<< TestsFor::Person->test_constructor() >> method. Except as you can see in our
 example above, we've B<hardcoded> the class name, meaning that we won't be
 testing our code appropriately. The code using the
 L<Test::Class::Moose::Role::AutoUse> role doesn't hardcode the class name (at
 least, it shouldn't), so when we call the inherited
-C<TestsFor::Person::Employee->test_constructor()> method, it constructs a
+C<< TestsFor::Person::Employee->test_constructor() >> method, it constructs a
 C<TestsFor::Person::Employee> object, not a C<TestsFor::Person> object.
 
 Some might argue that this is a strawman and we should have done this:
@@ -196,10 +196,20 @@ L<http://search.cpan.org/dist/Test-Class-Moose/>
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by Curtis "Ovid" Poe.
