@@ -1,5 +1,5 @@
 package Test::Class::Moose::Role::Executor;
-$Test::Class::Moose::Role::Executor::VERSION = '0.60';
+$Test::Class::Moose::Role::Executor::VERSION = '0.61';
 # ABSTRACT: Common code for Runner classes
 
 use 5.10.0;
@@ -271,7 +271,7 @@ sub _tcm_run_test_method {
     my $report  = Test::Class::Moose::Report::Method->new(
         { name => $test_method, instance_report => $instance_report } );
 
-    $self->test_report->current_class->add_test_method($report);
+    $self->test_report->current_instance->add_test_method($report);
     my $config = $self->test_configuration;
 
     my $builder = $config->builder;
@@ -348,7 +348,9 @@ sub test_classes {
         push @classes => $class if $class->isa('Test::Class::Moose');
     }
 
-    # eventually we'll want to control the test class order
+    if ( $self->test_configuration->randomize_classes ) {
+        return shuffle(@classes);
+    }
     return sort @classes;
 }
 
@@ -364,12 +366,22 @@ Test::Class::Moose::Role::Executor - Common code for Runner classes
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by Curtis "Ovid" Poe.
