@@ -1,5 +1,5 @@
 package Test::Class::Moose::Role::Parallel;
-$Test::Class::Moose::Role::Parallel::VERSION = '0.60';
+$Test::Class::Moose::Role::Parallel::VERSION = '0.61';
 # ABSTRACT: Deprecated parallel runner role - see docs for details
 
 use 5.10.0;
@@ -25,7 +25,7 @@ Test::Class::Moose::Role::Parallel - Deprecated parallel runner role - see docs
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 DESCRIPTION
 
@@ -38,10 +38,20 @@ L<Test::Class::Moose::Runner> class:
         jobs => 4,
     )->runtests();
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by Curtis "Ovid" Poe.
