@@ -1,5 +1,5 @@
 package Test::Class::Moose::Role::ParameterizedInstances;
-$Test::Class::Moose::Role::ParameterizedInstances::VERSION = '0.60';
+$Test::Class::Moose::Role::ParameterizedInstances::VERSION = '0.61';
 # ABSTRACT: run tests against multiple instances of a test class
 
 use Moose::Role;
@@ -28,12 +28,22 @@ Test::Class::Moose::Role::ParameterizedInstances - run tests against multiple in
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by Curtis "Ovid" Poe.
