@@ -1,5 +1,5 @@
 package Test::Class::Moose::Role::Timing;
-$Test::Class::Moose::Role::Timing::VERSION = '0.60';
+$Test::Class::Moose::Role::Timing::VERSION = '0.61';
 # ABSTRACT: Report timing role
 
 use Moose::Role;
@@ -57,7 +57,7 @@ Test::Class::Moose::Role::Timing - Report timing role
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 DESCRIPTION
 
@@ -77,10 +77,20 @@ Returns a L<Test::Class::Moose::Report::Time> object. This object
 represents the duration of this class or method. The duration may be "0" if
 it's an abstract class with no tests run.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by Curtis "Ovid" Poe.
