@@ -1,5 +1,5 @@
 package Test::Class::Moose::Runner;
-$Test::Class::Moose::Runner::VERSION = '0.60';
+$Test::Class::Moose::Runner::VERSION = '0.61';
 # ABSTRACT: Runner for Test::Class::Moose tests
 
 use 5.10.0;
@@ -79,7 +79,7 @@ Test::Class::Moose::Runner - Runner for Test::Class::Moose tests
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -137,6 +137,12 @@ details.
 
 Boolean. Will run test methods in a random order.
 
+=item * C<randomize_classes>
+
+Boolean. Will run test classes in a random order. Note that if you specify an
+explicit list of classes in C<test_classes>, these classes will be run in the
+order you specify.
+
 =item * C<builder>
 
 Defaults to C<< Test::Builder->new >>. You can supply your own builder if you
@@ -267,10 +273,20 @@ that class will be not be run in a child process. All test classes which can't
 be run in parallel are run sequentially after all parallelizable classes have
 run.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by Curtis "Ovid" Poe.
