@@ -1,5 +1,5 @@
 package Test::Class::Moose::Tutorial;
-$Test::Class::Moose::Tutorial::VERSION = '0.60';
+$Test::Class::Moose::Tutorial::VERSION = '0.61';
 # ABSTRACT: A starting guide for Test::Class::Moose
 
 # there is no code here, but we're moving this from .pod to .pm to try to work
@@ -18,7 +18,7 @@ Test::Class::Moose::Tutorial - A starting guide for Test::Class::Moose
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 Getting Started
 
@@ -151,7 +151,7 @@ inspect your test environment.
 =head1 Test Class Composition
 
 The most important reason to choose a class test over a procedural test (using
-only C<Test::More>) is class composition. 
+only C<Test::More>) is class composition.
 
 =head2 Inheritance
 
@@ -247,7 +247,7 @@ and call the C<test_skip> method with the reason we're skipping the test.
         my ( $test ) = @_;
         fail "This doesn't work!";
     }
-    
+
     sub test_setup {
         my $test = shift;
         if ( $test->test_report->current_method->name eq 'test_will_fail' ) {
@@ -359,10 +359,20 @@ Here is the bare minimum you need to get started using C<Test::Class::Moose>
 
 Doug Bell: https://github.com/preaction
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by Curtis "Ovid" Poe.
